@@ -1,3 +1,7 @@
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
+
 use std::{convert::TryInto, io::Write};
 
 use crate::u3v::{Error, Result};
@@ -126,6 +130,13 @@ impl ReadMem {
         })
     }
 
+    /// Returns maximum read length that corresponding ack length fit into `maximum_ack_len`.
+    pub fn maximum_read_length(maximum_ack_len: usize) -> u16 {
+        (maximum_ack_len - CommandPacket::<ReadMem>::ACK_HEADER_LENGTH)
+            .try_into()
+            .unwrap_or(u16::MAX)
+    }
+
     #[must_use]
     pub fn read_length(&self) -> u16 {
         self.read_length
